import { RetryOptions } from './lib/handleRetry';
export declare type DefaultGretchResponse = any;
export declare type DefaultGretchError = any;
export declare type GretchResponse<T = DefaultGretchResponse, A = DefaultGretchError> = {
    url: string;
    status: number;
    data: undefined;
    error: A;
    response: Response;
} | {
    url: string;
    status: number;
    data: T;
    error: undefined;
    response: Response;
};
export declare type GretchHooks = {
    before?: (request: Request, opts: GretchOptions) => void;
    after?: (response: GretchResponse, opts: GretchOptions) => void;
};
export declare type GretchOptions = {
    baseURL?: string;
    json?: {
        [key: string]: any;
    };
    retry?: RetryOptions | boolean;
    timeout?: number;
    onException?: (e: Error) => void;
    hooks?: GretchHooks;
    headers?: {
        [key: string]: any;
    } & RequestInit['headers'];
    [key: string]: any;
} & RequestInit;
export declare type GretchInstance<T, A> = {
    flush(): Promise<{
        url: string;
        status: number;
        response: Response;
    }>;
    arrayBuffer: () => Promise<GretchResponse<T, A>>;
    blob: () => Promise<GretchResponse<T, A>>;
    formData: () => Promise<GretchResponse<T, A>>;
    json: () => Promise<GretchResponse<T, A>>;
    text: () => Promise<GretchResponse<T, A>>;
};
export declare function gretch<T = DefaultGretchResponse, A = DefaultGretchError>(url: string, opts?: GretchOptions): GretchInstance<T, A>;
export declare function create(defaultOpts?: GretchOptions): <T = any, A = any>(url: string, opts?: GretchOptions) => GretchInstance<T, A>;
